import { ElementRef, OnDestroy, OnInit } from '@angular/core';
import { HashMap, MaybeArray, TranslocoMissingHandler, TranslocoScope, TranslocoService } from '@ngneat/transloco';
import { StringLiteralTranspiler } from './transpilers/string-literal-transpiler';
import { RecursiveArray } from './utils/array';
import { TranslationMarkupTranspiler } from './translation-markup-transpiler.model';
/**
 * Component that supports rendering of translations including HTML markup.
 */
export declare class TranslocoMarkupComponent implements OnInit, OnDestroy {
    /** Reference to the element which serves as the host for the component instance. */
    private readonly hostElement;
    /** `TranslocoService` instance that is to be used for loading translations and obtaining the Transloco configuration. */
    private readonly translocoService;
    /** Handler used for translation keys for which no translation value is defined in the active language. */
    private readonly missingHandler;
    /** Translation scope that is provided via the module/component injectors. */
    private readonly providedScope;
    /** Language that is provided via the module/component injectors. */
    private readonly providedLanguage;
    /** Markup transpilers provided via the module/component injectors. */
    private readonly providedTranspilers;
    /** Transpiler that is used for expanding string interpolation expressions. */
    private readonly stringInterpolationTranspiler;
    /** Transpiler used for rendering all unprocessed tokens in the translation values as literal text. */
    private readonly stringLiteralTranspiler;
    /** Key of the translation text that needs to be displayed. If no value is specified, the component will render an empty element. */
    translationKey?: string;
    /** Optional object that contains the values to be used for parameterized translation texts. */
    translationParameters?: HashMap;
    /** Language in which the text is the displayed. Overrides the provided language and language set using the translation service. */
    inlineLanguage?: string;
    /** Optional translation scope. */
    inlineScope?: string;
    /** Transpilers used to parse and render translation texts with markup. Merged with the provided transpilers. */
    inlineTranspilers?: MaybeArray<TranslationMarkupTranspiler>;
    /** Whether the inline transpilers should be merged with the provided ones. If set to `false` only the inline transpilers are used. */
    mergeTranspilers?: boolean;
    /** Root subscription to which all subscriptions are added that depend on the life cycle of the component instance. */
    private readonly subscriptions;
    /**
     * Creates a new `TranslocoMarkupComponent` instance.
     */
    constructor(
    /** Reference to the element which serves as the host for the component instance. */
    hostElement: ElementRef<HTMLElement>, 
    /** `TranslocoService` instance that is to be used for loading translations and obtaining the Transloco configuration. */
    translocoService: TranslocoService, 
    /** Handler used for translation keys for which no translation value is defined in the active language. */
    missingHandler: TranslocoMissingHandler, 
    /** Translation scope that is provided via the module/component injectors. */
    providedScope: MaybeArray<TranslocoScope> | null, 
    /** Language that is provided via the module/component injectors. */
    providedLanguage: string | null, 
    /** Markup transpilers provided via the module/component injectors. */
    providedTranspilers: RecursiveArray<TranslationMarkupTranspiler> | null, 
    /** Transpiler that is used for expanding string interpolation expressions. */
    stringInterpolationTranspiler: TranslationMarkupTranspiler, 
    /** Transpiler used for rendering all unprocessed tokens in the translation values as literal text. */
    stringLiteralTranspiler: StringLiteralTranspiler);
    /**
     * Initializes the component. When this method is called it starts listening for input property changes on the component and language
     * changes from the `TranslocoService`. This results in a stream containing the rendering function, which is executed for every change
     * to render the translation text including markup to the host element of the component instance.
     */
    ngOnInit(): void;
    /**
     * Called when the component is destroyed. Will cleanup any active subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Determines the translation value for the specified `key` and `translations`. Will return the first value of a translation which
     * contains the specified key. If no such translation exists, the `TranslocoMissingHandler` is used to obtain a value. For translations
     * where the value is an empty string the `TranslocoMissingHandler` is also used to determine if such values are allowed. If so, the
     * function will also return an empty string as translation value. When empty values are not allowed these will be considered as a
     * missing translation value for the tested translation.
     *
     * @param   key          Key for which the translation value is to be retrieved.
     * @param   translations Set of translations which are to be checked for the translation value identified by `key` parameter.
     * @returns              An object that defines the translation value and the translation dictionary containing the value.
     */
    private getTranslationValue;
}
